from setuptools import setup, find_packages


setup(
    name="pythons_helpers",
    version="0.1.0",
    description="A collection of helpful python functions",
    long_description=open("README.md", encoding="UTF-8").read(),
    url="",
    author="8au",
    license="MIT",
    keywords="python helpers, python3 helpers, pythonhelpers, helperfunctions, helperfunctionspython, helperfunctionspython3",
    packages=find_packages(),
    install_requires=['python3'],
)
